@@ -34,21 +34,22 @@
 #include <glib-object.h>
 #include <libcinnamon-desktop/gnome-rr.h>
 
-typedef struct GnomeRROutputInfoPrivate GnomeRROutputInfoPrivate;
-typedef struct GnomeRRConfigPrivate GnomeRRConfigPrivate;
+typedef struct _GnomeRROutputInfo GnomeRROutputInfo;
+typedef struct _GnomeRROutputInfoClass GnomeRROutputInfoClass;
+typedef struct _GnomeRROutputInfoPrivate GnomeRROutputInfoPrivate;
 
-typedef struct
+struct _GnomeRROutputInfo
 {
     GObject parent;
 
     /*< private >*/
     GnomeRROutputInfoPrivate *priv;
-} GnomeRROutputInfo;
+};
 
-typedef struct
+struct _GnomeRROutputInfoClass
 {
     GObjectClass parent_class;
-} GnomeRROutputInfoClass;
+};
 
 #define GNOME_TYPE_RR_OUTPUT_INFO                  (gnome_rr_output_info_get_type())
 #define GNOME_RR_OUTPUT_INFO(obj)                  (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_TYPE_RR_OUTPUT_INFO, GnomeRROutputInfo))
@@ -57,9 +58,11 @@ typedef struct
 #define GNOME_IS_RR_OUTPUT_INFO_CLASS(klass)       (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_TYPE_RR_OUTPUT_INFO))
 #define GNOME_RR_OUTPUT_INFO_GET_CLASS(obj)        (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_TYPE_RR_OUTPUT_INFO, GnomeRROutputInfoClass))
 
+G_DEFINE_AUTOPTR_CLEANUP_FUNC(GnomeRROutputInfo, g_object_unref)
+
 GType gnome_rr_output_info_get_type (void);
 
-const char *gnome_rr_output_info_get_name (GnomeRROutputInfo *self);
+char *gnome_rr_output_info_get_name (GnomeRROutputInfo *self);
 
 gboolean gnome_rr_output_info_is_active  (GnomeRROutputInfo *self);
 void     gnome_rr_output_info_set_active (GnomeRROutputInfo *self, gboolean active);
@@ -67,22 +70,17 @@ void     gnome_rr_output_info_set_active (GnomeRROutputInfo *self, gboolean acti
 void gnome_rr_output_info_get_geometry (GnomeRROutputInfo *self, int *x, int *y, int *width, int *height);
 void gnome_rr_output_info_set_geometry (GnomeRROutputInfo *self, int  x, int  y, int  width, int  height);
 
-float gnome_rr_output_info_get_scale (GnomeRROutputInfo *self);
-void gnome_rr_output_info_set_scale (GnomeRROutputInfo *self, float scale);
-
-int gnome_rr_output_info_get_refresh_rate (GnomeRROutputInfo *self);
+int  gnome_rr_output_info_get_refresh_rate (GnomeRROutputInfo *self);
 void gnome_rr_output_info_set_refresh_rate (GnomeRROutputInfo *self, int rate);
 
-double gnome_rr_output_info_get_refresh_rate_f (GnomeRROutputInfo *self);
-void gnome_rr_output_info_set_refresh_rate_f (GnomeRROutputInfo *self, double rate);
-
 GnomeRRRotation gnome_rr_output_info_get_rotation (GnomeRROutputInfo *self);
 void            gnome_rr_output_info_set_rotation (GnomeRROutputInfo *self, GnomeRRRotation rotation);
+gboolean        gnome_rr_output_info_supports_rotation (GnomeRROutputInfo *self, GnomeRRRotation rotation);
 
 gboolean gnome_rr_output_info_is_connected     (GnomeRROutputInfo *self);
-void     gnome_rr_output_info_get_vendor       (GnomeRROutputInfo *self, gchar* vendor);
-guint    gnome_rr_output_info_get_product      (GnomeRROutputInfo *self);
-guint    gnome_rr_output_info_get_serial       (GnomeRROutputInfo *self);
+const char *gnome_rr_output_info_get_vendor    (GnomeRROutputInfo *self);
+const char *gnome_rr_output_info_get_product   (GnomeRROutputInfo *self);
+const char *gnome_rr_output_info_get_serial    (GnomeRROutputInfo *self);
 double   gnome_rr_output_info_get_aspect_ratio (GnomeRROutputInfo *self);
 char    *gnome_rr_output_info_get_display_name (GnomeRROutputInfo *self);
 
@@ -92,26 +90,27 @@ void     gnome_rr_output_info_set_primary (GnomeRROutputInfo *self, gboolean pri
 int gnome_rr_output_info_get_preferred_width  (GnomeRROutputInfo *self);
 int gnome_rr_output_info_get_preferred_height (GnomeRROutputInfo *self);
 
-void gnome_rr_output_info_get_flags (GnomeRROutputInfo *self,
-                                     gboolean          *doublescan,
-                                     gboolean          *interlaced,
-                                     gboolean          *vsync);
-void gnome_rr_output_info_set_flags (GnomeRROutputInfo *self,
-                                     gboolean           doublescan,
-                                     gboolean           interlaced,
-                                     gboolean           vsync);
-typedef struct
+gboolean gnome_rr_output_info_get_underscanning (GnomeRROutputInfo *self);
+void     gnome_rr_output_info_set_underscanning (GnomeRROutputInfo *self, gboolean underscanning);
+
+gboolean gnome_rr_output_info_is_primary_tile (GnomeRROutputInfo *self);
+
+typedef struct _GnomeRRConfig GnomeRRConfig;
+typedef struct _GnomeRRConfigClass GnomeRRConfigClass;
+typedef struct _GnomeRRConfigPrivate GnomeRRConfigPrivate;
+
+struct _GnomeRRConfig
 {
     GObject parent;
 
     /*< private >*/
     GnomeRRConfigPrivate *priv;
-} GnomeRRConfig;
+};
 
-typedef struct
+struct _GnomeRRConfigClass
 {
     GObjectClass parent_class;
-} GnomeRRConfigClass;
+};
 
 #define GNOME_TYPE_RR_CONFIG                  (gnome_rr_config_get_type())
 #define GNOME_RR_CONFIG(obj)                  (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_TYPE_RR_CONFIG, GnomeRRConfig))
@@ -120,35 +119,27 @@ typedef struct
 #define GNOME_IS_RR_CONFIG_CLASS(klass)       (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_TYPE_RR_CONFIG))
 #define GNOME_RR_CONFIG_GET_CLASS(obj)        (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_TYPE_RR_CONFIG, GnomeRRConfigClass))
 
+G_DEFINE_AUTOPTR_CLEANUP_FUNC(GnomeRRConfig, g_object_unref)
+
 GType               gnome_rr_config_get_type     (void);
 
 GnomeRRConfig      *gnome_rr_config_new_current  (GnomeRRScreen  *screen,
 						  GError        **error);
-GnomeRRConfig      *gnome_rr_config_new_stored   (GnomeRRScreen  *screen,
+gboolean            gnome_rr_config_load_current (GnomeRRConfig  *self,
 						  GError        **error);
-gboolean                gnome_rr_config_load_current (GnomeRRConfig  *self,
-						      GError        **error);
-gboolean                gnome_rr_config_load_filename (GnomeRRConfig  *self,
-						       const gchar    *filename,
-						       GError        **error);
 gboolean            gnome_rr_config_match        (GnomeRRConfig  *config1,
 						  GnomeRRConfig  *config2);
 gboolean            gnome_rr_config_equal	 (GnomeRRConfig  *config1,
 						  GnomeRRConfig  *config2);
-gboolean            gnome_rr_config_save         (GnomeRRConfig  *configuration,
-						  GError        **error);
 void                gnome_rr_config_sanitize     (GnomeRRConfig  *configuration);
 gboolean            gnome_rr_config_ensure_primary (GnomeRRConfig  *configuration);
 
-gboolean	    gnome_rr_config_apply_with_time (GnomeRRConfig  *configuration,
-						     GnomeRRScreen  *screen,
-						     guint32         timestamp,
-						     GError        **error);
-
-gboolean            gnome_rr_config_apply_from_filename_with_time (GnomeRRScreen  *screen,
-								   const char     *filename,
-								   guint32         timestamp,
-								   GError        **error);
+gboolean	    gnome_rr_config_apply  (GnomeRRConfig  *configuration,
+					    GnomeRRScreen  *screen,
+					    GError        **error);
+gboolean	    gnome_rr_config_apply_persistent  (GnomeRRConfig  *configuration,
+						       GnomeRRScreen  *screen,
+						       GError        **error);
 
 gboolean            gnome_rr_config_applicable   (GnomeRRConfig  *configuration,
 						  GnomeRRScreen  *screen,
@@ -156,16 +147,6 @@ gboolean            gnome_rr_config_applicable   (GnomeRRConfig  *configuration,
 
 gboolean            gnome_rr_config_get_clone    (GnomeRRConfig  *configuration);
 void                gnome_rr_config_set_clone    (GnomeRRConfig  *configuration, gboolean clone);
-guint               gnome_rr_config_get_base_scale (GnomeRRConfig *self);
-void                gnome_rr_config_set_base_scale (GnomeRRConfig *self,
-                                                    guint base_scale);
-gboolean            gnome_rr_config_get_auto_scale (GnomeRRConfig *self);
-void                gnome_rr_config_set_auto_scale (GnomeRRConfig *self,
-                                                    gboolean       auto_scale);
 GnomeRROutputInfo **gnome_rr_config_get_outputs  (GnomeRRConfig  *configuration);
 
-char *gnome_rr_config_get_backup_filename (void);
-char *gnome_rr_config_get_intended_filename (void);
-char *gnome_rr_config_get_legacy_filename (void);
-
 #endif
